"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getEslintConfig = ({ target, rulesOverrides }) => {
    return {
        parser: '@typescript-eslint/parser',
        plugins: [
            '@typescript-eslint',
            'eslint-comments',
            'react-hooks',
            'jest',
            'array-func',
            'promise',
            'import',
            'prettier'
        ],
        extends: [
            'airbnb',
            'airbnb/hooks',
            'plugin:promise/recommended',
            'plugin:@typescript-eslint/recommended',
            'plugin:array-func/recommended',
            'plugin:eslint-comments/recommended',
            'prettier'
        ],
        env: {
            es6: true,
            node: target === 'node',
            browser: target === 'browser'
        },
        overrides: [
            {
                files: ['**/*.test.js', '**/*.spec.js'],
                env: { jest: true },
                plugins: ['jest'],
                ...require('eslint-plugin-jest').configs.recommended // eslint-disable-line global-require
            }
        ],
        rules: {
            'no-continue': 0,
            'no-await-in-loop': 0,
            'prettier/prettier': 'warn',
            'import/prefer-default-export': 0,
            'import/order': 0,
            'import/export': 0,
            'func-names': 0,
            'no-restricted-syntax': 0,
            'no-underscore-dangle': 0,
            'no-use-before-define': 0,
            'guard-for-in': 0,
            strict: 0,
            'no-control-regex': 0,
            'no-console': ['warn', { allow: ['warn', 'error', 'info', 'dir'] }],
            'import/no-unresolved': 0,
            'arrow-body-style': 0,
            'no-nested-ternary': 0,
            'consistent-return': 0,
            'no-prototype-builtins': 0,
            quotes: [2, 'single', { avoidEscape: true }],
            'no-plusplus': 0,
            'promise/always-return': 0,
            'max-classes-per-file': 0,
            '@typescript-eslint/no-unused-vars': ['error', { argsIgnorePattern: '^_', args: 'after-used' }],
            '@typescript-eslint/explicit-function-return-type': 0,
            '@typescript-eslint/no-explicit-any': 0,
            '@typescript-eslint/no-var-requires': 0,
            '@typescript-eslint/indent': 0,
            '@typescript-eslint/camelcase': 0,
            '@typescript-eslint/no-use-before-define': 0,
            '@typescript-eslint/explicit-member-accessibility': 0,
            '@typescript-eslint/ban-ts-ignore': 0,
            ...rulesOverrides
        }
    };
};
//# sourceMappingURL=eslint.js.map