"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const consola_1 = __importDefault(require("consola"));
const chalk_1 = __importDefault(require("chalk"));
const figures_1 = __importDefault(require("figures"));
const getPrettyLoggableRepresentation = (msg) => typeof msg === 'object' && process.env.AWS_LAMBDA_RUNTIME_API && !(msg instanceof Error) ? JSON.stringify(msg) : msg;
exports.infoLog = (message, ...args) => consola_1.default.info(getPrettyLoggableRepresentation(message), ...args.map(getPrettyLoggableRepresentation));
exports.warnLog = (message, ...args) => consola_1.default.warn(getPrettyLoggableRepresentation(message), ...args.map(getPrettyLoggableRepresentation));
exports.successLog = (message, ...args) => consola_1.default.success(getPrettyLoggableRepresentation(message), ...args.map(getPrettyLoggableRepresentation));
exports.errorLog = (error) => console.error(exports.getPrettyErrorMessage(typeof error === 'string' ? new Error(error) : error));
exports.startLog = (message, ...args) => consola_1.default.start(getPrettyLoggableRepresentation(message), ...args.map(getPrettyLoggableRepresentation));
exports.beautifyErrorLine = (line) => {
    if (/(.*)Error:/.test(line)) {
        const errorName = line.match(/(.*)Error:/)[0];
        return line.replace(errorName, `${chalk_1.default.redBright(figures_1.default.cross)} ${errorName} `);
    }
    if (/webpack\\bootstrap|webpack\/bootstrap/.test(line) ||
        line.includes('internal/modules/cjs/loader.js') ||
        (/(.*)webpack:(.*).(.*):(.*)/.test(line) && !line.match(/ {4}at /))) {
        return null;
    }
    if (line.includes('webpack:') && !line.match(/'webpack\\'|'webpack\/'/)) {
        return chalk_1.default.cyan(line.replace(/at(.*)webpack:/, 'at (')).replace(/\/|\\/, '');
    }
    if (line.includes('node_modules')) {
        return line
            .replace(/(\(.*)node_modules/, '(node_modules')
            .replace(/\/(.*)node_modules/, 'node_modules')
            .replace(/C:(.*)node_modules/, 'node_modules');
    }
    return line;
};
exports.getPrettyErrorMessage = error => {
    const stackTraceArray = error.stackTrace || error.stack.split('\n');
    let prettyMessage = `${chalk_1.default.redBright(figures_1.default.cross)} ${stackTraceArray[0]}`;
    for (let i = 1; i < stackTraceArray.length; i++) {
        const line = stackTraceArray[i].replace(/[\u001b\u009b][[()#;?]*(?:[0-9]{1,4}(?:;[0-9]{0,4})*)?[0-9A-ORZcf-nqry=><]/g, '');
        prettyMessage += `\n${exports.beautifyErrorLine(line)}`;
    }
    return prettyMessage;
};
//# sourceMappingURL=logging.js.map