"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const consola_1 = __importDefault(require("consola"));
const execa_1 = __importDefault(require("execa"));
const stream_1 = require("stream");
const logging_1 = require("./logging");
exports.wait = (ms) => {
    return new Promise(resolve => setTimeout(resolve, ms));
};
const applyAll = (functionsArray, value) => {
    let res = value;
    for (const fn of functionsArray) {
        res = fn(res);
    }
    return res;
};
class StreamTransformer extends stream_1.Transform {
    constructor(lineTransformers = []) {
        super({ objectMode: true });
        this.lastLineData = '';
        this.lineTransformers = [];
        this.lineTransformers = lineTransformers;
    }
    _transform(chunk, _encoding, cb) {
        let data = String(chunk);
        if (this.lastLineData) {
            data = this.lastLineData + data;
        }
        const lines = data.split('\n');
        // eslint-disable-next-line prefer-destructuring
        this.lastLineData = lines.splice(lines.length - 1, 1)[0];
        for (const line of lines) {
            const transformedLine = applyAll(this.lineTransformers, line);
            if (transformedLine === null)
                continue;
            this.push(`${applyAll(this.lineTransformers, line)}\n`);
        }
        cb();
    }
    _flush(cb) {
        if (!this.lastLineData) {
            return cb();
        }
        this.push(`${applyAll(this.lineTransformers, this.lastLineData)}\n`);
        this.lastLineData = '';
        cb();
    }
}
const getTransformer = (transformer) => {
    return Array.isArray(transformer) ? transformer : [transformer];
};
exports.plainExec = async ({ cmd, args = [], env = {}, transformStderr = [], transformStdout = [], logFailedCommand = false, logCommandToExecute = false }) => {
    if (logCommandToExecute)
        consola_1.default.info(`Executing command: ${cmd}`);
    const childProcess = execa_1.default(cmd, args, { env: { FORCE_COLOR: '1', ...env } });
    if (transformStderr) {
        childProcess.stderr.pipe(new StreamTransformer(getTransformer(transformStderr))).pipe(process.stderr);
    }
    else {
        childProcess.stderr.pipe(process.stderr);
    }
    if (transformStdout) {
        childProcess.stdout.pipe(new StreamTransformer(getTransformer(transformStdout))).pipe(process.stdout);
    }
    else {
        childProcess.stdout.pipe(process.stdout);
    }
    const result = await childProcess.catch(err => {
        if (logFailedCommand)
            logging_1.errorLog(`\n${err}`);
    });
    return result;
};
exports.exec = (props) => {
    return exports.plainExec({
        ...props,
        transformStderr: getTransformer(props.transformStderr || []).concat(logging_1.beautifyErrorLine)
    });
};
//# sourceMappingURL=utils.js.map